@@ -137,15 +137,15 @@ MODEL_CONFIGS = [
     ModelConfig(
         short_name="ModernBuildings_SD21",
         # config_path="configs/stable-diffusion-v2-inference-v.yaml",
-        config_path="configs/stable-diffusion-v2-inference.yaml",
-        weights_url="https://civitai.com/api/download/models/3002",
+        config_path="configs/stable-diffusion-v2-modern-buildings.yaml",
+        weights_url="https://huggingface.co/smereces/2.1-SD-Modern-Buildings-Style-MD/resolve/main/midjourneyi_16500_lora.ckpt",
         default_image_size=768,
     ),
     ModelConfig(
         short_name="DreamLikeHumans",
         config_path="configs/stable-diffusion-v1.yaml",
         weights_url="https://huggingface.co/dreamlike-art/dreamlike-photoreal-2.0/resolve/main/dreamlike-photoreal-2.0.ckpt",
-        default_image_size=768,
+        default_image_size=512,
     ),
     # ModelConfig(
     #     short_name="SD-2.0-upscale",
